@@ -11,6 +11,8 @@ from .bin_outputs import bin_outputs
 from .load_chr_sizes   import load_chr_sizes
 from .load_rec_map     import load_rec_map
 from .load_Bmap       import load_Bmap
+# Sample data utilities
+from .sample_data import download_sample_data, get_sample_data_dir
 # DFE utilities
 from . import dfe_helper
 
@@ -21,6 +23,8 @@ __all__ = [
     "SPECIES", "generateParams",
     # handlers
     "load_bed_gff", "bin_outputs", "load_chr_sizes", "load_rec_map", "load_Bmap",
+    # sample data
+    "download_sample_data", "get_sample_data_dir",
     # DFE utilities
     "dfe_helper",
 ]
\ No newline at end of file
